==> vtk6-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkAddMembershipArray.java <==
// java wrapper for vtkAddMembershipArray object
//

package vtk;
import vtk.*;

public class vtkAddMembershipArray extends vtkPassInputTypeAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetFieldType_2();
  public int GetFieldType()
    { return GetFieldType_2(); }

  private native void SetFieldType_3(int id0);
  public void SetFieldType(int id0)
    { SetFieldType_3(id0); }

  private native int GetFieldTypeMinValue_4();
  public int GetFieldTypeMinValue()
    { return GetFieldTypeMinValue_4(); }

  private native int GetFieldTypeMaxValue_5();
  public int GetFieldTypeMaxValue()
    { return GetFieldTypeMaxValue_5(); }

  private native void SetOutputArrayName_6(String id0);
  public void SetOutputArrayName(String id0)
    { SetOutputArrayName_6(id0); }

  private native String GetOutputArrayName_7();
  public String GetOutputArrayName()
    { return GetOutputArrayName_7(); }

  private native void SetInputArrayName_8(String id0);
  public void SetInputArrayName(String id0)
    { SetInputArrayName_8(id0); }

  private native String GetInputArrayName_9();
  public String GetInputArrayName()
    { return GetInputArrayName_9(); }

  private native void SetInputValues_10(vtkAbstractArray id0);
  public void SetInputValues(vtkAbstractArray id0)
    { SetInputValues_10(id0); }

  private native long GetInputValues_11();
  public vtkAbstractArray GetInputValues() {
    long temp = GetInputValues_11();

    if (temp == 0) return null;
    return (vtkAbstractArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkAddMembershipArray() { super(); }

  public vtkAddMembershipArray(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-2-armv6h.pkg.tar.xz: vtk/vtkAddMembershipArray.java <==
// java wrapper for vtkAddMembershipArray object
//

package vtk;
import vtk.*;

public class vtkAddMembershipArray extends vtkPassInputTypeAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetFieldType_2();
  public int GetFieldType()
    { return GetFieldType_2(); }

  private native void SetFieldType_3(int id0);
  public void SetFieldType(int id0)
    { SetFieldType_3(id0); }

  private native int GetFieldTypeMinValue_4();
  public int GetFieldTypeMinValue()
    { return GetFieldTypeMinValue_4(); }

  private native int GetFieldTypeMaxValue_5();
  public int GetFieldTypeMaxValue()
    { return GetFieldTypeMaxValue_5(); }

  private native void SetOutputArrayName_6(String id0);
  public void SetOutputArrayName(String id0)
    { SetOutputArrayName_6(id0); }

  private native String GetOutputArrayName_7();
  public String GetOutputArrayName()
    { return GetOutputArrayName_7(); }

  private native void SetInputArrayName_8(String id0);
  public void SetInputArrayName(String id0)
    { SetInputArrayName_8(id0); }

  private native String GetInputArrayName_9();
  public String GetInputArrayName()
    { return GetInputArrayName_9(); }

  private native void SetInputValues_10(vtkAbstractArray id0);
  public void SetInputValues(vtkAbstractArray id0)
    { SetInputValues_10(id0); }

  private native long GetInputValues_11();
  public vtkAbstractArray GetInputValues() {
    long temp = GetInputValues_11();

    if (temp == 0) return null;
    return (vtkAbstractArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkAddMembershipArray() { super(); }

  public vtkAddMembershipArray(long id) { super(id); }
  public native long   VTKInit();

}
